from setuptools import setup

setup(name='geo_qua',
      version='0.0',
      description='Geometric sequence and quadratic equation',
      packages=['geo_qua'],
      author_email='olegisupov542@gmail.com',
      zip_safe=False)
